@@ -29,7 +29,10 @@ from bec_lib.logger import bec_logger
 from bec_lib.utils.rpc_utils import rgetattr
 from bec_server.device_server.bec_message_handler import BECMessageHandler
 from bec_server.device_server.devices.config_update_handler import ConfigUpdateHandler
-from bec_server.device_server.devices.device_serializer import get_device_info
+from bec_server.device_server.devices.device_serializer import (
+    disable_lazy_wait_for_connection,
+    get_device_info,
+)
 
 logger = bec_logger.logger
 
@@ -105,13 +108,31 @@ class DeviceManagerDS(DeviceManagerBase):
         super().initialize(bootstrap_server)
 
     def _reload_action(self) -> None:
-        pass
+        """
+        The _reload_action on the device server is a no-op, as devices are reloaded
+        through the config update handler.
+        """
 
-    def _add_action(self, msg: messages.DeviceConfigMessage) -> None:
-        pass
+    def _add_action(self, config: dict) -> None:
+        """
+        The _add_action on the device server is a no-op, as devices are added
+        through the config update handler.
+        """
 
-    def _remove_action(self, msg: messages.DeviceConfigMessage) -> None:
-        pass
+    def _remove_action(self, config: dict) -> None:
+        """
+        The _remove_action on the device server is a no-op, as devices are removed
+        through the config update handler.
+        """
+
+    @property
+    def current_session(self) -> dict:
+        """
+        Get the current device session.
+        Please note that the internal _session variable is private as it is shared across
+        multiple services and typically should not be accessed directly.
+        """
+        return self._session
 
     @staticmethod
     def _get_device_class(dev_type: str) -> type:
@@ -222,8 +243,7 @@ class DeviceManagerDS(DeviceManagerBase):
         reload_msg = messages.DeviceConfigMessage(action="reload", config={})
         self.connector.send(MessageEndpoints.device_config_update(), reload_msg)
 
-    @staticmethod
-    def update_config(obj: OphydObject, config: dict) -> None:
+    def update_config(self, obj: OphydObject, config: dict) -> None:
         """Update an ophyd device's config
 
         Args:
@@ -232,39 +252,54 @@ class DeviceManagerDS(DeviceManagerBase):
 
         """
         if hasattr(obj, "_update_device_config"):
-            obj._update_device_config(config)
-        else:
-            for config_key, config_value in config.items():
-                # first handle the ophyd exceptions...
-                if config_key == "limits":
-                    if hasattr(obj, "low_limit_travel") and hasattr(obj, "high_limit_travel"):
-                        low_limit_status = obj.low_limit_travel.set(config_value[0])
-                        high_limit_status = obj.high_limit_travel.set(config_value[1])
-                        low_limit_status.wait()
-                        high_limit_status.wait()
-                        continue
-                if config_key == "labels":
-                    if not config_value:
-                        config_value = set()
-                    # pylint: disable=protected-access
-                    obj._ophyd_labels_ = set(config_value)
-                    continue
-                if not hasattr(obj, config_key):
-                    raise DeviceConfigError(
-                        f"Unknown config parameter {config_key} for device of type"
-                        f" {obj.__class__.__name__}."
-                    )
+            # If the device has implemented its own config update method, use it
+            # pylint: disable=protected-access
+            obj._update_device_config(config)  # type: ignore
+            return
 
-                config_attr = getattr(obj, config_key)
-                if isinstance(config_attr, ophyd.Signal):
-                    config_attr.set(config_value)
-                elif callable(config_attr):
-                    config_attr(config_value)
-                else:
-                    setattr(obj, config_key, config_value)
+        signal_updated = False
+        for config_key, config_value in config.items():
+            # first handle the ophyd exceptions...
+            if config_key == "limits":
+                if hasattr(obj, "low_limit_travel") and hasattr(obj, "high_limit_travel"):
+                    low_limit_status = obj.low_limit_travel.set(config_value[0])  # type: ignore
+                    high_limit_status = obj.high_limit_travel.set(config_value[1])  # type: ignore
+                    # Respect Timeout to avoid blocking the device server indefinitely
+                    low_limit_status.wait(timeout=2)
+                    high_limit_status.wait(timeout=2)
+                    continue
+            if config_key == "labels":
+                if not config_value:
+                    config_value = set()
+                # pylint: disable=protected-access
+                obj._ophyd_labels_ = set(config_value)
+                continue
+            if not hasattr(obj, config_key):
+                raise DeviceConfigError(
+                    f"Unknown config parameter {config_key} for device of type"
+                    f" {obj.__class__.__name__}."
+                )
+
+            config_attr = getattr(obj, config_key)
+            if isinstance(config_attr, ophyd.Signal):
+                config_attr.set(config_value).wait(timeout=2)
+                if not hasattr(config_attr, "_auto_monitor"):
+                    # only signal values that are not auto monitored need
+                    # to trigger a manual buffer update
+                    signal_updated = True
+            elif callable(config_attr):
+                config_attr(config_value)
+            else:
+                setattr(obj, config_key, config_value)
+
+        if signal_updated:
+            # re-initialize the device buffer to reflect the updated signal values
+            self.devices[obj.name].initialize_device_buffer(self.connector)
 
     @staticmethod
-    def construct_device_obj(dev: dict, device_manager: DeviceManagerDS) -> (OphydObject, dict):
+    def construct_device_obj(
+        dev: dict, device_manager: DeviceManagerDS
+    ) -> tuple[OphydObject, dict]:
         """
         Construct a device object from a device config dictionary.
 
@@ -335,7 +370,15 @@ class DeviceManagerDS(DeviceManagerBase):
         # refresh the device info
         pipe = self.connector.pipeline()
         self.reset_device_data(obj, pipe)
-        raised_exc = self.publish_device_info(obj, pipe)
+        # Try to connect to the device, needs wait_for_all to include lazy signals e.g. AD detectors
+        raised_exc = self.connect_device(obj, wait_for_all=True)
+        # Publish device info with connect = True if no exception was raised during connection
+        # Otherwise publish with connect = False
+        connect = True if raised_exc is None else False
+        # If .describe() fails for connect=True, we rerun with connect=False
+        # and return the exception. This will later be raised even if
+        # connect_device succeeded.
+        publish_device_exc = self.publish_device_info(obj, connect=connect, pipe=pipe)
         pipe.execute()
 
         # insert the created device obj into the device manager
@@ -347,24 +390,41 @@ class DeviceManagerDS(DeviceManagerBase):
         if raised_exc:
             raise raised_exc
 
+        if publish_device_exc:
+            raise publish_device_exc
+
         if not enabled:
             return opaas_obj
 
         self.initialize_enabled_device(opaas_obj)
 
+        obj = opaas_obj.obj
+
+        # Add subscriptions to device events and signal if supported by the device
+        if hasattr(obj, "event_types"):
+            self._subscribe_to_device_events(obj, opaas_obj)
+            self._subscribe_to_bec_device_events(obj)
+            self._subscribe_to_auto_monitors(obj)
+            self._subscribe_to_limit_updates(obj)
+            self._subscribe_to_bec_signals(obj)
+
+        # Update the config at last as this may also set signals
         self.update_config(obj, config)
 
-        obj = opaas_obj.obj
-        # add subscriptions
-        if not hasattr(obj, "event_types"):
-            return opaas_obj
-        self._subscribe_to_device_events(obj, opaas_obj)
-        self._subscribe_to_bec_device_events(obj)
-        self._subscribe_to_auto_monitors(obj)
-        self._subscribe_to_bec_signals(obj)
-
         return opaas_obj
 
+    def _subscribe_to_limit_updates(self, obj: OphydObject):
+        """
+        Subscribe to limit updates if the device has low_limit_travel and high_limit_travel signals.
+
+        Args:
+            obj (OphydObject): Ophyd object to subscribe to limit updates
+        """
+        if hasattr(obj, "low_limit_travel") and hasattr(obj.low_limit_travel, "subscribe"):
+            obj.low_limit_travel.subscribe(self._obj_callback_limit_change, run=False)
+        if hasattr(obj, "high_limit_travel") and hasattr(obj.high_limit_travel, "subscribe"):
+            obj.high_limit_travel.subscribe(self._obj_callback_limit_change, run=False)
+
     def _subscribe_to_device_events(self, obj: OphydObject, opaas_obj: DSDevice):
         """Subscribe to device events"""
 
@@ -373,7 +433,7 @@ class DeviceManagerDS(DeviceManagerBase):
         elif "value" in obj.event_types:
             obj.subscribe(self._obj_callback_readback, event_type="value", run=opaas_obj.enabled)
         if hasattr(obj, "motor_is_moving"):
-            obj.motor_is_moving.subscribe(self._obj_callback_is_moving, run=opaas_obj.enabled)
+            obj.motor_is_moving.subscribe(self._obj_callback_is_moving, run=opaas_obj.enabled)  # type: ignore
 
     def _subscribe_to_bec_device_events(self, obj: OphydObject):
         """
@@ -416,7 +476,7 @@ class DeviceManagerDS(DeviceManagerBase):
         if not hasattr(obj, "component_names"):
             return
 
-        for component_name in obj.component_names:
+        for component_name in obj.component_names:  # type: ignore
             component = getattr(obj, component_name)
             if hasattr(component, "component_names"):
                 self._subscribe_to_auto_monitors(component)
@@ -439,14 +499,13 @@ class DeviceManagerDS(DeviceManagerBase):
         if not hasattr(obj, "walk_signals"):
             # If the object does not have walk_components, it is likely a simple signal
             return
-        signal_walk = obj.walk_signals()
+        signal_walk = obj.walk_signals()  # type: ignore
         for _ancestor, _signal_name, signal in signal_walk:
             if isinstance(signal, BECMessageSignal):
                 signal.subscribe(callback=self._obj_callback_bec_message_signal, run=False)
 
     def initialize_enabled_device(self, opaas_obj):
         """connect to an enabled device and initialize the device buffer"""
-        self.connect_device(opaas_obj.obj)
         if hasattr(opaas_obj.obj, "on_connected"):
             opaas_obj.obj.on_connected()
         opaas_obj.initialize_device_buffer(self.connector)
@@ -466,47 +525,72 @@ class DeviceManagerDS(DeviceManagerBase):
         obj.initialized = False
 
     @staticmethod
-    def connect_device(obj, wait_for_all=False):
-        """establish a connection to a device"""
+    def connect_device(
+        obj: ophyd.OphydObject, wait_for_all: bool = False, timeout: float = 30, **kwargs
+    ) -> None | Exception:
+        """
+        Establish a connection to a device.
+
+        Args:
+            obj (OphydObject): The device object to connect to.
+            wait_for_all (bool): Whether to wait for all signals to connect.
+                                 Default is False
+            timeout (float): Timeout in seconds for the connection attempt to all signals.
+                             Default is 30 seconds.
+
+        Raises:
+            ConnectionError: If the connection could not be established.
+        """
+
         try:
-            if obj.connected:
-                return
             if hasattr(obj, "controller"):
-                obj.controller.on()
+                obj.controller.on()  # type: ignore
                 return
             if hasattr(obj, "wait_for_connection"):
                 try:
-                    obj.wait_for_connection(all_signals=wait_for_all, timeout=30)
+                    with disable_lazy_wait_for_connection(obj):
+                        obj.wait_for_connection(all_signals=wait_for_all, timeout=timeout)  # type: ignore
                 except TypeError:
-                    obj.wait_for_connection(timeout=30)
+                    with disable_lazy_wait_for_connection(obj):
+                        obj.wait_for_connection(timeout=timeout)  # type: ignore
                 return
+            # Check connected last, as an ophyd device with only lazy signals will always
+            # be obj.connected == True. Therefore, we have to call wait_for_connection first
+            # for any ophyd devices. This anyways falls back to checking obj.connected.
+            # For simulated devices or non-ophyd devices that do not implement wait_for_connection
+            # we still want to check obj.connected to allow for them to load.
+            if obj.connected:
+                return
+
             logger.error(
                 f"Device {obj.name} does not implement the socket controller interface nor"
                 " wait_for_connection and cannot be turned on."
             )
-            raise ConnectionError(f"Failed to establish a connection to device {obj.name}")
-        except Exception:
-            error_traceback = traceback.format_exc()
-            logger.error(f"{error_traceback}. Failed to connect to {obj.name}.")
-            raise ConnectionError(f"Failed to establish a connection to device {obj.name}")
+            return ConnectionError(f"Failed to establish a connection to device {obj.name}")
+        except Exception as exc:
+            logger.error(f"Failed to connect for {obj.name}: {exc}")
+            return exc
 
-    def publish_device_info(self, obj: OphydObject, pipe=None) -> None | Exception:
+    def publish_device_info(
+        self, obj: OphydObject, connect: bool = True, pipe=None
+    ) -> None | Exception:
         """
         Publish the device info to redis. The device info contains
         inter alia the class name, user functions and signals.
 
         Args:
             obj (_type_): _description_
+            connect (bool): Whether to connect to the device before getting the info. Defaults to True.
         """
         try:
-            interface = get_device_info(obj)
+            interface = get_device_info(obj, connect=connect)
             self.connector.set(
                 MessageEndpoints.device_info(obj.name),
                 messages.DeviceInfoMessage(device=obj.name, info=interface),
                 pipe,
             )
         except Exception as exc:
-            logger.error(f"Failed to get device info for {obj.name}: {exc}")
+            logger.error(f"Failed to publish device info for {obj.name}: {exc}")
             interface = get_device_info(obj, connect=False)
             self.connector.set(
                 MessageEndpoints.device_info(obj.name),
@@ -522,6 +606,20 @@ class DeviceManagerDS(DeviceManagerBase):
         self.connector.delete(MessageEndpoints.device_read_configuration(obj.name), pipe)
         self.connector.delete(MessageEndpoints.device_info(obj.name), pipe)
 
+    def _obj_callback_limit_change(self, *_args, obj: OphydObject, **kwargs):
+        """Callback for limit changes"""
+        if not obj.connected:
+            return
+        name = obj.root.name
+        limits = {
+            "low": {"value": obj.root.low_limit_travel.get()},
+            "high": {"value": obj.root.high_limit_travel.get()},
+        }
+        dev_msg = messages.DeviceMessage(signals=limits)
+        pipe = self.connector.pipeline()
+        self.connector.set_and_publish(MessageEndpoints.device_limits(name), dev_msg, pipe=pipe)
+        pipe.execute()
+
     def _obj_callback_readback(self, *_args, obj: OphydObject, **kwargs):
         if not obj.connected:
             return
@@ -760,3 +858,14 @@ class DeviceManagerDS(DeviceManagerBase):
         if not isinstance(value, messages.BECMessage):
             return
         self._bec_message_handler.emit(obj, value)
+
+    def shutdown(self):
+        """Shutdown the device manager and disconnect all devices"""
+        for device in self.devices.values():
+            try:
+                logger.info(f"Disconnecting device {device.name}")
+                self.disconnect_device(device.obj)
+            except Exception:
+                logger.error(f"Failed to disconnect device {device.name}: {traceback.format_exc()}")
+        self.devices.flush()
+        super().shutdown()
