@@ -70,7 +70,8 @@ class AsyncWriter(threading.Thread):
                 Each tuple contains (device_name, component_name and the signal info)
         """
         super().__init__(target=self._run, daemon=True, name="AsyncWriter")
-        self.file_path = file_path
+        self.file_path = file_path if isinstance(file_path, str) else str(file_path)
+        self.tmp_file_path = self.file_path.replace(".h5", ".tmp")
         self.scan_id = scan_id
         self.scan_number = scan_number
         self.devices = devices
@@ -173,23 +174,27 @@ class AsyncWriter(threading.Thread):
                 self.poll_and_write_data()
             # run one last time to get any remaining data
             self.poll_and_write_data(final=True)
-            logger.info(f"Finished writing async data file {self.file_path}")
+            logger.info(f"Finished writing async data file {self.tmp_file_path}")
         # pylint: disable=broad-except
         except Exception:
             content = traceback.format_exc()
             # self.send_file_message(done=True, successful=False)
-            logger.error(f"Error writing async data file {self.file_path}: {content}")
+            logger.error(f"Error writing async data file {self.tmp_file_path}: {content}")
+            error_info = messages.ErrorInfo(
+                error_message=f"Error writing async data file {self.tmp_file_path}",
+                compact_error_message=traceback.format_exc(limit=0),
+                exception_type="AsyncWriterError",
+            )
             self.connector.raise_alarm(
                 severity=Alarms.WARNING,
-                alarm_type="AsyncWriterError",
-                source={"file_path": self.file_path},
-                msg=f"Error writing async data file {self.file_path}: {content}",
+                info=error_info,
                 metadata={"scan_id": self.scan_id, "scan_number": self.scan_number},
             )
 
     def send_file_message(self, done: bool, successful: bool) -> None:
         """
         Send a file message to inform other services about current writing status
+        We will send the final file name, not the temporary one.
 
         Args:
             done (bool): Whether the writing is done
@@ -228,7 +233,7 @@ class AsyncWriter(threading.Thread):
 
         """
         if self.file_handle is None:
-            self.file_handle = h5py.File(self.file_path, "w")
+            self.file_handle = h5py.File(self.tmp_file_path, "w")
 
         f = self.file_handle
 
@@ -264,11 +269,16 @@ class AsyncWriter(threading.Thread):
                             self.write_timestamp_data(signal_group, value)
                         else:  # pragma: no cover
                             # this should never happen as the keys are fixed in the pydantic model
+                            msg = f"Unknown key: {key}. Data will not be written."
+                            error_info = messages.ErrorInfo(
+                                error_message=msg,
+                                compact_error_message=msg,
+                                exception_type="ValueError",
+                                device=device_name,
+                            )
                             self.connector.raise_alarm(
                                 severity=Alarms.WARNING,
-                                alarm_type="ValueError",
-                                source={"device": device_name},
-                                msg=f"Unknown key: {key}. Data will not be written.",
+                                info=error_info,
                                 metadata={"scan_id": self.scan_id, "scan_number": self.scan_number},
                             )
 
@@ -308,11 +318,15 @@ class AsyncWriter(threading.Thread):
             # store the data to be written after the scan is complete
             self.device_data_replace[signal_group.name] = value
         else:
+            msg = f"Unknown async update type: {update_type}. Data will not be written."
             self.connector.raise_alarm(
                 severity=Alarms.WARNING,
-                alarm_type="ValueError",
-                source={"device": signal_group.name},
-                msg=f"Unknown async update type: {update_type}. Data will not be written.",
+                info=messages.ErrorInfo(
+                    error_message=msg,
+                    compact_error_message=msg,
+                    exception_type="ValueError",
+                    device=signal_group.name,
+                ),
                 metadata={"scan_id": self.scan_id, "scan_number": self.scan_number},
             )
 
@@ -365,11 +379,15 @@ class AsyncWriter(threading.Thread):
         else:
             current_shape = signal_group["value"].shape
             if max_shape[1] is not None and value.shape[1] > max_shape[1]:
+                msg = f"Data for {signal_group.name} exceeds the defined max_shape {max_shape}. Data will not be written."
                 self.connector.raise_alarm(
                     severity=Alarms.WARNING,
-                    alarm_type="ValueError",
-                    source={"device": signal_group.name},
-                    msg=f"Data for {signal_group.name} exceeds the defined max_shape {max_shape}. Data will not be written.",
+                    info=messages.ErrorInfo(
+                        error_message=msg,
+                        compact_error_message=msg,
+                        exception_type="ValueError",
+                        device=signal_group.name,
+                    ),
                     metadata={"scan_id": self.scan_id, "scan_number": self.scan_number},
                 )
                 return
@@ -390,11 +408,15 @@ class AsyncWriter(threading.Thread):
 
         if len(max_shape) != 2:
             # We currently only support 2D datasets for the 'add_slice' async update type
+            msg = f"Invalid max_shape for async update type 'add_slice': {max_shape}. max_shape cannot exceed two dimensions. Data will not be written."
             self.connector.raise_alarm(
                 severity=Alarms.WARNING,
-                alarm_type="ValueError",
-                source={"device": signal_group.name},
-                msg=f"Invalid max_shape for async update type 'add_slice': {max_shape}. max_shape cannot exceed two dimensions. Data will not be written.",
+                info=messages.ErrorInfo(
+                    error_message=msg,
+                    compact_error_message=msg,
+                    exception_type="ValueError",
+                    device=signal_group.name,
+                ),
                 metadata={"scan_id": self.scan_id, "scan_number": self.scan_number},
             )
             return
@@ -418,11 +440,15 @@ class AsyncWriter(threading.Thread):
                 if value.ndim < len(max_shape):
                     value = value.reshape((1,) + value.shape)
                 if value.shape[1] > max_shape[1]:
+                    msg = f"Data for {signal_group.name} exceeds the defined max_shape {max_shape}. Data will be truncated."
                     self.connector.raise_alarm(
                         severity=Alarms.WARNING,
-                        alarm_type="ValueError",
-                        source={"device": signal_group.name, "slice": row_index},
-                        msg=f"Data for {signal_group.name} exceeds the defined max_shape {max_shape}. Data will be truncated.",
+                        info=messages.ErrorInfo(
+                            error_message=msg,
+                            compact_error_message=msg,
+                            exception_type="ValueError",
+                            device=signal_group.name,
+                        ),
                         metadata={"scan_id": self.scan_id, "scan_number": self.scan_number},
                     )
                     value = value[:, : max_shape[1]]
@@ -444,11 +470,15 @@ class AsyncWriter(threading.Thread):
         else:
             col_index = self.cursor[signal_group.name].get(row_index, 0)
             if col_index + len(value) > max_shape[1]:
+                msg = f"Added data slice for {signal_group.name} exceeds the defined max_shape {max_shape}. Data will be truncated."
                 self.connector.raise_alarm(
                     severity=Alarms.WARNING,
-                    alarm_type="ValueError",
-                    source={"device": signal_group.name, "slice": row_index},
-                    msg=f"Added data slice for {signal_group.name} exceeds the defined max_shape {max_shape}. Data will be truncated.",
+                    info=messages.ErrorInfo(
+                        error_message=msg,
+                        compact_error_message=msg,
+                        exception_type="ValueError",
+                        device=signal_group.name,
+                    ),
                     metadata={"scan_id": self.scan_id, "scan_number": self.scan_number},
                 )
                 value = value[: max_shape[1] - col_index]
