@@ -17,7 +17,7 @@ from bec_lib.alarm_handler import Alarms
 from bec_lib.endpoints import MessageEndpoints
 from bec_lib.logger import bec_logger
 
-from .errors import LimitError, ScanAbortion
+from .errors import DeviceInstructionError, LimitError, ScanAbortion
 from .instruction_handler import InstructionHandler
 from .scan_assembler import ScanAssembler
 
@@ -79,17 +79,16 @@ class QueueManager:
             self.queues[scan_queue].insert(msg, position=position)
         # pylint: disable=broad-except
         except Exception as exc:
-            if len(exc.args) > 0:
-                content = exc.args[0]
-            else:
-                content = ""
+            content = traceback.format_exc()
             logger.error(content)
+            error_info = messages.ErrorInfo(
+                error_message=content,
+                compact_error_message=traceback.format_exc(limit=0),
+                exception_type=exc.__class__.__name__,
+                device=None,
+            )
             self.connector.raise_alarm(
-                severity=Alarms.MAJOR,
-                source=msg.content,
-                msg=content,
-                alarm_type=exc.__class__.__name__,
-                metadata=msg.metadata,
+                severity=Alarms.MAJOR, info=error_info, metadata=msg.metadata
             )
 
     def add_queue(self, queue_name: str) -> None:
@@ -529,7 +528,7 @@ class ScanQueue:
                     and len(self.queue) > 0
                     and self.queue[0].status != InstructionQueueStatus.PENDING
                 ):
-                    logger.info(f"Removing queue item {self.queue[0].describe()} from queue")
+                    logger.debug(f"Removing queue item {self.queue[0].describe()} from queue")
                     self.queue.popleft()
                     self.queue_manager.send_queue_status()
 
@@ -863,25 +862,35 @@ class RequestBlockQueue:
             self._pull_request_block()
             return next(self.active_rb.instructions)
         except LimitError as limit_error:
+            error_info = messages.ErrorInfo(
+                error_message=limit_error.args[0],
+                compact_error_message=traceback.format_exc(limit=0),
+                exception_type=limit_error.__class__.__name__,
+                device=limit_error.device,
+            )
             self.scan_queue.queue_manager.connector.raise_alarm(
-                severity=Alarms.MAJOR,
-                source=self.active_rb.msg.content,
-                msg=limit_error.args[0],
-                alarm_type=limit_error.__class__.__name__,
-                metadata=self._get_metadata_for_alarm(),
+                severity=Alarms.MAJOR, info=error_info, metadata=self._get_metadata_for_alarm()
             )
             self.instruction_queue.stopped = True
             raise ScanAbortion from limit_error
+        except DeviceInstructionError as exc:
+            logger.error(exc.message)
+            self.scan_queue.queue_manager.connector.raise_alarm(
+                severity=Alarms.MAJOR, info=exc.error_info, metadata=self._get_metadata_for_alarm()
+            )
+            raise
         # pylint: disable=broad-except
         except Exception as exc:
             content = traceback.format_exc()
             logger.error(content)
+            error_info = messages.ErrorInfo(
+                error_message=str(exc),
+                compact_error_message=traceback.format_exc(limit=0),
+                exception_type=exc.__class__.__name__,
+                device=None,
+            )
             self.scan_queue.queue_manager.connector.raise_alarm(
-                severity=Alarms.MAJOR,
-                source=self.active_rb.msg.content,
-                msg=content,
-                alarm_type=exc.__class__.__name__,
-                metadata=self._get_metadata_for_alarm(),
+                severity=Alarms.MAJOR, info=error_info, metadata=self._get_metadata_for_alarm()
             )
             raise ScanAbortion from exc
 
@@ -933,7 +942,7 @@ class InstructionQueueItem:
     def status(self, val: InstructionQueueStatus) -> None:
         """update the status of the instruction queue. By doing so, it will
         also update its worker and publish the updated queue."""
-        logger.info(
+        logger.debug(
             f"Setting status of instruction queue {self.queue_id} to {val.name} from thread {threading.current_thread().name}"
         )
         self._status = val
