@@ -119,7 +119,7 @@ class ScanStubStatus:
         if message.status == "completed":
             self.set_done(message.result)
         elif message.status == "error":
-            self.set_failed(message.error_message)
+            self.set_failed(message.error_info)
         else:
             self.set_running()
 
@@ -133,15 +133,18 @@ class ScanStubStatus:
         self.done = True
         self._future.set_result(result)
 
-    def set_failed(self, error_message: str = ""):
+    def set_failed(self, error_info: messages.ErrorInfo | None = None):
         """
         Set the status object to failed.
 
         Args:
-            error_message (str, optional): Error message. Defaults to "".
+            error_info (messages.ErrorInfo, optional): Error information. Defaults to None.
         """
         self.done = True
-        self._future.set_exception(DeviceInstructionError(error_message))
+        exc = DeviceInstructionError(error_info.compact_error_message if error_info else None)
+        if error_info:
+            exc.set_info(error_info)
+        self._future.set_exception(exc)
 
     def set_running(self):
         """
@@ -178,6 +181,11 @@ class ScanStubStatus:
             all(st._done for st in self._sub_status_objects) if self._sub_status_objects else True
         )
 
+    @staticmethod
+    def _raise_if_failed(obj: concurrent.futures.Future) -> None:
+        if obj.exception() is not None:
+            raise obj.exception()
+
     def wait(
         self, min_wait: float = None, timeout: float = np.inf, logger_wait=5
     ) -> ScanStubStatus:
@@ -205,8 +213,10 @@ class ScanStubStatus:
 
         if self._done and self._get_sub_status_done():
             self._done_checked = True
+            self._raise_if_failed(self._future)
             for st in self._sub_status_objects:
                 st._done_checked = True
+                self._raise_if_failed(st._future)
             return self
 
         # pylint: disable=protected-access
@@ -221,8 +231,7 @@ class ScanStubStatus:
                 futures, timeout=increment, return_when=concurrent.futures.FIRST_EXCEPTION
             )
             for future in done:
-                if future.exception() is not None:
-                    raise future.exception()
+                self._raise_if_failed(future)
             wait_time += increment
             if wait_time >= timeout:
                 raise TimeoutError("The wait operation timed out.")
@@ -569,13 +578,15 @@ class ScanStubs:
 
         if stage_device_names_without_async:
             stage_device_names_without_async = sorted(stage_device_names_without_async)
-        instr = messages.DeviceInstructionMessage(
-            device=stage_device_names_without_async,
-            action="stage",
-            parameter={},
-            metadata={"device_instr_id": status._device_instr_id},
-        )
-        yield instr
+            instr = messages.DeviceInstructionMessage(
+                device=stage_device_names_without_async,
+                action="stage",
+                parameter={},
+                metadata={"device_instr_id": status._device_instr_id},
+            )
+            yield instr
+        else:
+            status.set_done()
         status.wait()
         return status
 
