@@ -13,7 +13,7 @@ from bec_lib.endpoints import MessageEndpoints
 from bec_lib.file_utils import compile_file_components
 from bec_lib.logger import bec_logger
 
-from .errors import ScanAbortion
+from .errors import DeviceInstructionError, ScanAbortion
 from .scan_queue import InstructionQueueItem, InstructionQueueStatus, RequestBlock
 from .scan_stubs import ScanStubStatus
 
@@ -413,29 +413,53 @@ class ScanWorker(threading.Thread):
                     instr.metadata["scan_id"] = queue.queue.active_rb.scan_id
                     instr.metadata["queue_id"] = queue.queue_id
                     self._instruction_step(instr)
-            except Exception as exc_return_to_start:
-                # if the return_to_start fails, raise the original exception
+            except DeviceInstructionError as exc_di:
                 content = traceback.format_exc()
                 logger.error(content)
                 self.connector.raise_alarm(
                     severity=Alarms.MAJOR,
-                    source={"ScanWorker": "_process_instructions"},
-                    msg=content,
-                    alarm_type=exc_return_to_start.__class__.__name__,
+                    info=exc_di.error_info,
                     metadata=self._get_metadata_for_alarm(),
                 )
+                raise ScanAbortion from exc_di
+            except Exception as exc_return_to_start:
+                # if the return_to_start fails, raise the original exception
+                content = traceback.format_exc()
+                logger.error(content)
+                error_info = messages.ErrorInfo(
+                    error_message=content,
+                    compact_error_message=traceback.format_exc(limit=0),
+                    exception_type=exc_return_to_start.__class__.__name__,
+                    device=None,
+                )
+                self.connector.raise_alarm(
+                    severity=Alarms.MAJOR, info=error_info, metadata=self._get_metadata_for_alarm()
+                )
                 raise ScanAbortion from exc
             raise ScanAbortion from exc
-        except Exception as exc:
+        except DeviceInstructionError as exc_di:
             content = traceback.format_exc()
             logger.error(content)
             self.connector.raise_alarm(
                 severity=Alarms.MAJOR,
-                source={"ScanWorker": "_process_instructions"},
-                msg=content,
-                alarm_type=exc.__class__.__name__,
+                info=exc_di.error_info,
                 metadata=self._get_metadata_for_alarm(),
             )
+
+            raise ScanAbortion from exc_di
+        except Exception as exc:
+            content = traceback.format_exc()
+            logger.error(content)
+            error_info = messages.ErrorInfo(
+                error_message=content,
+                compact_error_message=traceback.format_exc(limit=0),
+                exception_type=exc.__class__.__name__,
+                device=None,
+            )
+            self.connector.raise_alarm(
+                severity=Alarms.MAJOR, info=error_info, metadata=self._get_metadata_for_alarm()
+            )
+
             raise ScanAbortion from exc
         queue.is_active = False
         queue.status = InstructionQueueStatus.COMPLETED
@@ -542,17 +566,19 @@ class ScanWorker(threading.Thread):
         except Exception as exc:
             content = traceback.format_exc()
             logger.error(content)
+            error_info = messages.ErrorInfo(
+                error_message=content,
+                compact_error_message=traceback.format_exc(limit=0),
+                exception_type=exc.__class__.__name__,
+                device=None,
+            )
             self.connector.raise_alarm(
-                severity=Alarms.MAJOR,
-                source={"ScanWorker": "run"},
-                msg=content,
-                alarm_type=exc.__class__.__name__,
-                metadata=self._get_metadata_for_alarm(),
+                severity=Alarms.MAJOR, info=error_info, metadata=self._get_metadata_for_alarm()
             )
             if self.queue_name in self.parent.queue_manager.queues:
                 self.parent.queue_manager.queues[self.queue_name].abort()
             self.reset()
-            logger.error(f"Scan worker stopped: {exc}. Unrecoverable error.")
+            logger.critical(f"Scan worker stopped: {exc}. Unrecoverable error.")
 
     def shutdown(self):
         """shutdown the scan worker"""
