@@ -10,6 +10,7 @@ from typing import TYPE_CHECKING, Any, Literal
 
 import numpy as np
 
+from bec_lib import messages
 from bec_lib.alarm_handler import Alarms
 from bec_lib.device import DeviceBase
 from bec_lib.devicemanager import DeviceManagerBase
@@ -54,8 +55,10 @@ def unpack_scan_args(scan_args: dict[str, Any]) -> list:
     return args
 
 
-def get_2D_raster_pos(axis, snaked=True):
-    """get_2D_raster_post calculates and returns the positions for a 2D
+def get_ND_grid_pos(axes: list[np.ndarray], snaked: bool = True) -> np.ndarray:
+    """
+    Generate N-dimensional grid positions.
+    It creates a grid of positions for N dimensions, with optional snaking behavior.
 
     snaked==True:
         ->->->->-
@@ -67,20 +70,27 @@ def get_2D_raster_pos(axis, snaked=True):
         ->->->->-
 
     Args:
-        axis (list): list of positions for each axis
-        snaked (bool, optional): If true, the positions will be calculcated for a snake scan. Defaults to True.
+        axes (list of arrays): list of 1D arrays for each axis
+        snaked (bool, optional): If True, the grid is generated in a "snaked"
+            pattern across all dimensions.
 
     Returns:
-        array: calculated positions
+        np.ndarray: shape (num_points, N)
     """
 
-    x_grid, y_grid = np.meshgrid(axis[0], axis[1])
-    if snaked:
-        y_grid.T[::2] = np.fliplr(y_grid.T[::2])
-    x_flat = x_grid.T.ravel()
-    y_flat = y_grid.T.ravel()
-    positions = np.vstack((x_flat, y_flat)).T
-    return positions
+    def _get_positions_recursively(current_axes):
+        if len(current_axes) == 1:
+            return [[v] for v in current_axes[0]]
+
+        positions = []
+        for i, val in enumerate(current_axes[0]):
+            sub_positions = _get_positions_recursively(current_axes[1:])
+            if snaked and (i % 2 == 1):
+                sub_positions.reverse()
+            positions.extend([[val] + sp for sp in sub_positions])
+        return positions
+
+    return np.array(_get_positions_recursively(axes))
 
 
 # pylint: disable=too-many-arguments
@@ -285,7 +295,8 @@ class RequestBase(ABC):
                 if not low_limit <= pos_axis <= high_limit:
                     raise LimitError(
                         f"Target position {pos} for motor {dev} is outside of range: [{low_limit},"
-                        f" {high_limit}]"
+                        f" {high_limit}]",
+                        device=dev,
                     )
 
     def update_scan_motors(self):
@@ -549,13 +560,14 @@ class ScanBase(RequestBase, PathOptimizerMixin):
             exclude_done=False, exclude_checked=True
         )
         if unchecked_status_objects:
-            self.connector.raise_alarm(
-                severity=Alarms.WARNING,
-                source={"Scan": self.scan_name},
-                msg=f"Scan completed with unchecked status objects: {unchecked_status_objects}. Use .wait() or .done within the scan to check their status.",
-                alarm_type="ScanCleanupWarning",
-                metadata=metadata,
+            msg = f"Scan completed with unchecked status objects: {unchecked_status_objects}. Use .wait() or .done within the scan to check their status."
+            error_info = messages.ErrorInfo(
+                error_message=msg,
+                compact_error_message=msg,
+                exception_type="UncheckedStatusObjectsWarning",
+                device=None,
             )
+            self.connector.raise_alarm(severity=Alarms.WARNING, info=error_info, metadata=metadata)
 
         # Check if there are any remaining status objects that are not done.
         # This is not an error but we send a warning and wait for them to complete.
@@ -563,13 +575,14 @@ class ScanBase(RequestBase, PathOptimizerMixin):
             exclude_done=True, exclude_checked=False
         )
         if remaining_status_objects:
-            self.connector.raise_alarm(
-                severity=Alarms.WARNING,
-                source={"Scan": self.scan_name},
-                msg=f"Scan completed with remaining status objects: {remaining_status_objects}",
-                alarm_type="ScanCleanupWarning",
-                metadata=metadata,
+            msg = f"Scan completed with remaining status objects: {remaining_status_objects}"
+            error_info = messages.ErrorInfo(
+                error_message=msg,
+                compact_error_message=msg,
+                exception_type="ScanCleanupWarning",
+                device=None,
             )
+            self.connector.raise_alarm(severity=Alarms.WARNING, info=error_info, metadata=metadata)
             for obj in remaining_status_objects:
                 obj.wait()
 
@@ -914,15 +927,36 @@ class Scan(ScanBase):
             burst_at_each_point=burst_at_each_point,
             **kwargs,
         )
+        self._last_pos = []
 
     def _calculate_positions(self):
-        axis = []
+        axes = []
+        self._last_pos = []
         for _, val in self.caller_args.items():
-            axis.append(np.linspace(val[0], val[1], val[2], dtype=float))
-        if len(axis) > 1:
-            self.positions = get_2D_raster_pos(axis, snaked=self.snaked)
-        else:
-            self.positions = np.vstack(tuple(axis)).T
+            axes.append(np.linspace(val[0], val[1], val[2], dtype=float))
+            self._last_pos.append(None)
+        self.positions = get_ND_grid_pos(axes, snaked=self.snaked)
+
+    def _move_scan_motors_and_wait(self, pos):
+        if pos is None:
+            return
+        if not isinstance(pos, list) and not isinstance(pos, np.ndarray):
+            pos = [pos]
+        if len(pos) == 0:
+            return
+        # Determine which motors changed
+        changed_values = []
+        changed_motors = []
+        for motor, new, old in zip(self.scan_motors, pos, self._last_pos):
+            if old is None or not np.isclose(new, old):
+                changed_motors.append(motor)
+                changed_values.append(new)
+
+        # Only move if something changed
+        if changed_motors:
+            yield from self.stubs.set(device=changed_motors, value=changed_values)
+
+        self._last_pos = list(pos)
 
 
 class FermatSpiralScan(ScanBase):
@@ -1229,7 +1263,8 @@ class ContLineScan(ScanBase):
             if not low_limit <= pos_axis <= high_limit:
                 raise LimitError(
                     f"Target position including offset {pos_axis} (offset: {self.offset}) for motor {self.device} is outside of range: [{low_limit},"
-                    f" {high_limit}]"
+                    f" {high_limit}]",
+                    device=self.device,
                 )
 
     def _at_each_point(self, _ind=None, _pos=None):
