@@ -112,11 +112,7 @@ def test_stop_devices(device_server_mock):
             stop.assert_called_once()
             assert raise_alarm.call_count == 1
             assert raise_alarm.call_args == mock.call(
-                severity=Alarms.WARNING,
-                source={"device": "samy", "method": "stop"},
-                msg=mock.ANY,
-                alarm_type=mock.ANY,
-                metadata=mock.ANY,
+                severity=Alarms.WARNING, info=mock.ANY, metadata=mock.ANY
             )
             # If stop raises an exception, the device server must get back to running state
             assert device_server.status == BECStatus.RUNNING
@@ -178,10 +174,10 @@ def test_assert_device_is_enabled(device_server_mock, instr):
     for dev in devices:
         if not device_server.device_manager.devices[dev].enabled:
             with pytest.raises(Exception) as exc_info:
-                device_server._assert_device_is_enabled(instr)
+                device_server.assert_device_is_enabled(instr)
             assert exc_info.value.args[0] == f"Cannot access disabled device {dev}."
         else:
-            device_server._assert_device_is_enabled(instr)
+            device_server.assert_device_is_enabled(instr)
 
 
 @pytest.mark.parametrize(
@@ -213,7 +209,7 @@ def test_assert_device_is_valid(device_server_mock, instr):
 
     if not devices:
         with pytest.raises(InvalidDeviceError):
-            device_server._assert_device_is_valid(instr)
+            device_server.assert_device_is_valid(instr)
         return
 
     if not isinstance(devices, list):
@@ -222,10 +218,10 @@ def test_assert_device_is_valid(device_server_mock, instr):
     for dev in devices:
         if dev not in device_server.device_manager.devices:
             with pytest.raises(InvalidDeviceError) as exc_info:
-                device_server._assert_device_is_valid(instr)
+                device_server.assert_device_is_valid(instr)
             assert exc_info.value.args[0] == f"There is no device with the name {dev}."
         else:
-            device_server._assert_device_is_enabled(instr)
+            device_server.assert_device_is_enabled(instr)
 
 
 @pytest.mark.parametrize(
@@ -243,9 +239,9 @@ def test_assert_device_is_valid(device_server_mock, instr):
 def test_handle_device_instructions_set(device_server_mock, instructions):
     device_server = device_server_mock
 
-    with mock.patch.object(device_server, "_assert_device_is_valid") as assert_device_is_valid_mock:
+    with mock.patch.object(device_server, "assert_device_is_valid") as assert_device_is_valid_mock:
         with mock.patch.object(
-            device_server, "_assert_device_is_enabled"
+            device_server, "assert_device_is_enabled"
         ) as assert_device_is_enabled_mock:
             with mock.patch.object(
                 device_server, "_update_device_metadata"
@@ -262,12 +258,10 @@ def test_handle_device_instructions_set(device_server_mock, instructions):
 
 def test_handle_device_instruction_raises_alarm(device_server_mock):
     device_server = device_server_mock
-    with mock.patch.object(device_server, "_assert_device_is_enabled", side_effect=RuntimeError):
+    with mock.patch.object(device_server, "assert_device_is_enabled", side_effect=RuntimeError):
         with mock.patch.object(device_server.connector, "raise_alarm") as raise_alarm:
             device_server.handle_device_instructions(mock.MagicMock())
-            raise_alarm.assert_called_once_with(
-                severity=Alarms.MAJOR, source=ANY, msg=ANY, alarm_type=ANY, metadata=ANY
-            )
+            raise_alarm.assert_called_once_with(severity=Alarms.MAJOR, info=ANY, metadata=ANY)
 
 
 @pytest.mark.parametrize(
@@ -291,11 +285,7 @@ def test_handle_device_instructions_limit_error(device_server_mock, instructions
             device_server.handle_device_instructions(instructions)
 
             alarm_mock.assert_called_once_with(
-                severity=Alarms.MAJOR,
-                source=instructions.content,
-                msg=ANY,
-                alarm_type="LimitError",
-                metadata=instructions.metadata,
+                severity=Alarms.MAJOR, info=ANY, metadata=instructions.metadata
             )
 
 
@@ -332,14 +322,14 @@ def test_handle_device_instructions_read(device_server_mock, instructions):
 @pytest.mark.parametrize("device_manager_class", [DeviceManagerDS])
 def test_handle_device_instructions_rpc(device_server_mock, instructions):
     device_server = device_server_mock
-    with mock.patch.object(device_server, "_assert_device_is_valid") as assert_device_is_valid_mock:
+    with mock.patch.object(device_server, "assert_device_is_valid") as assert_device_is_valid_mock:
         with mock.patch.object(
-            device_server, "_assert_device_is_enabled"
+            device_server, "assert_device_is_enabled"
         ) as assert_device_is_enabled_mock:
             with mock.patch.object(
                 device_server, "_update_device_metadata"
             ) as update_device_metadata_mock:
-                with mock.patch.object(device_server, "run_rpc") as rpc_mock:
+                with mock.patch.object(device_server.rpc_handler, "run_rpc") as rpc_mock:
                     device_server.handle_device_instructions(instructions)
                     rpc_mock.assert_called_once_with(instructions)
 
@@ -417,6 +407,9 @@ def test_complete_device(device_server_mock, instr):
     complete_mock = mock.MagicMock()
     device = instr.content["device"]
     oph_device = device_server.device_manager.devices.get(device)
+    status = DeviceStatus(oph_device)
+    status.set_finished()
+    complete_mock.return_value = status
     if device is not None:
         oph_device.obj.complete = complete_mock
     device_server._complete_device(instr)
@@ -465,7 +458,7 @@ def test_handle_device_instructions_pre_scan(device_server_mock, instructions):
             assert status.done is True
             assert send_response_mock.call_count == 2
             assert send_response_mock.call_args == mock.call(
-                "diid", True, done=True, error_message=None, result=None
+                "diid", True, done=True, error_info=None, result=None
             )
 
 
