@@ -8,7 +8,7 @@ from bec_lib.redis_connector import RedisConnector
 # to have it in autouse
 
 
-def fake_redis_server(host, port):
+def fake_redis_server(host, port, **kwargs):
     redis = fakeredis.FakeRedis()
     return redis
 
